@@ -235,8 +235,8 @@ def subscription_prompt(mlist, doc, cookie, userdesc):
     <p>Note: your password will be emailed to you once your subscription is
     confirmed.  You can change it by visiting your personal options page.
 
-    <p>Or hit <em>Cancel and discard</em> to cancel this subscription
-    request.""") + '<p><hr>'
+    <p>Or hit <em>Cancel my subscription request</em> if you no longer want to
+    subscribe to this list.""") + '<p><hr>'
     if mlist.subscribe_policy in (2, 3):
         # Confirmation is required
         result = _("""Your confirmation is required in order to continue with
@@ -348,6 +348,11 @@ def subscription_confirm(mlist, doc, cookie, cgidata):
             address that has already been unsubscribed.'''))
         except Errors.MMAlreadyAMember:
             doc.addError(_("You are already a member of this mailing list!"))
+        except Errors.HostileSubscriptionError:
+            doc.addError(_("""\
+            You were not invited to this mailing list.  The invitation has
+            been discarded, and both list administrators have been
+            alerted."""))
         else:
             # Use the user's preferred language
             i18n.set_language(lang)
