@@ -34,6 +34,7 @@ import errno
 import time
 import cgi
 import htmlentitydefs
+import email.Header
 import email.Iterators
 from types import UnicodeType
 from string import whitespace, digits
@@ -57,6 +58,7 @@ except NameError:
     False = 0
 
 EMPTYSTRING = ''
+UEMPTYSTRING = u''
 NL = '\n'
 DOT = '.'
 IDENTCHARS = ascii_letters + digits + '_'
@@ -145,12 +147,10 @@ def wrap(text, column=70, honor_leading_ws=True):
                     if eol == 0:
                         # break on whitespace after column
                         eol = column
-                        while eol < len(text) and \
-                              text[eol] not in whitespace:
+                        while eol < len(text) and text[eol] not in whitespace:
                             eol += 1
                         bol = eol
-                        while bol < len(text) and \
-                              text[bol] in whitespace:
+                        while bol < len(text) and text[bol] in whitespace:
                             bol += 1
                         bol -= 1
                     line = text[:eol+1] + '\n'
@@ -357,7 +357,7 @@ def check_global_password(response, siteadmin=True):
 
 
 def websafe(s):
-    return cgi.escape(s, quote=1)
+    return cgi.escape(s, quote=True)
 
 
 def nntpsplit(s):
@@ -796,6 +796,7 @@ def uncanonstr(s, lang=None):
         # Nope, it contains funny characters, so html-ref it
         return uquote(s)
 
+
 def uquote(s):
     a = []
     for c in s:
@@ -806,3 +807,15 @@ def uquote(s):
             a.append(c)
     # Join characters together and coerce to byte string
     return str(EMPTYSTRING.join(a))
+
+
+def oneline(s, cset):
+    # Decode header string in one line and convert into specified charset
+    try:
+        h = email.Header.make_header(email.Header.decode_header(s))
+        ustr = h.__unicode__()
+        line = UEMPTYSTRING.join(ustr.splitlines())
+        return line.encode(cset, 'replace')
+    except (LookupError, UnicodeError):
+        # possibly charset problem. return with undecoded string in one line.
+        return EMPTYSTRING.join(s.splitlines())
