@@ -1,8 +1,6 @@
 #! /usr/bin/env python
 
 """Convert the plain text FAQ file to its .ht template.
-
-Requires Python 2.0
 """
 
 import sys
@@ -48,7 +46,6 @@ FAQ Wizard</a> for more information.
     question = []
     answer = []
     faq = []
-    inquestion = 0
     while 1:
         line = lines[lineno][:-1]
 
